#!/bin/sh

echo "--- undo_unbind_ftdi_udev.sh ---"

SERIAL=
FILE="99-ftdi-unbind-by-serial.rules"
UDEV_PATH="/etc/udev/rules.d"

usage() {
  echo "Usage: $0 -s <serial> [-f <file>]"
  echo " -s  specify serial number."
  echo " -f  specify udev file. Optional. Default 99-ftdi-unbind-by-serial.rules"
  exit 1
  }
  
while getopts ":hv:p:s:f:" arg; do
  case $arg in
    s)  SERIAL=$OPTARG;;
    f)    FILE=$OPTARG;;
    h) usage;;
    *) usage;;
  esac
done
shift $((OPTIND-1))

if [ -z "$SERIAL" ]
then
  echo "Error: no serial specified"
  usage
fi

if [ -z "$FILE" ]
then
  echo "Error: empty file specified"
  usage
fi

FILE="$UDEV_PATH/$FILE"

echo "Undo addition of udev rule so VENDOR:PRODUCT:SERIAL=${VENDOR}:${PRODUCT}:${SERIAL} devices do not load ftdi_sio driver."
echo "Removing all lines containing SERIAL=${SERIAL} from file: ${FILE}"

LINE0=${SERIAL}
sudo sed -i "/${LINE0}/d" $FILE

sudo sed -i -E "/idVendor.*$VENDOR.*idProduct.*$PRODUCT.*serial.*$SERIAL.*MODE.*0666\"/d" $FILE
sudo sed -i -E "/idVendor.*$VENDOR.*idProduct.*$PRODUCT.*serial.*$SERIAL.*RUN.*ftdi_sio\/unbind/d" $FILE 

sudo service udev restart
echo "Need to unplug-plug devices for changes to take effect"